@@ -18,6 +18,17 @@ CONFIG_FILE_NAME_BANDIT = '.bandit'
 CONFIG_FILE_CONTENT_BANDIT = '''[bandit]
 '''
 
+# test coverage
+CONFIG_FILE_NAME_COVERAGE = '.coveragerc'
+CONFIG_FILE_CONTENT_COVERAGE = '''
+[run]
+source = .
+omit = ./venv/*,*tests*,*apps.py,*manage.py,*__init__.py,*migrations*,*asgi*,*wsgi*,*admin.py,*urls.py
+
+[report]
+omit = ./venv/*,*tests*,*apps.py,*manage.py,*__init__.py,*migrations*,*asgi*,*wsgi*,*admin.py,*urls.py
+'''
+
 # lighthouse
 CONFIG_FILE_NAME_LIGHTHOUSE = 'lighthouserc.json'
 CONFIG_FILE_CONTENT_LIGHTHOUSE = '''
